@@ -8,7 +8,8 @@ fn main() -> std::io::Result<()> {
         .version(crate_version!())
         .author(crate_authors!())
         .about("`linkr` operates ranges on chromosomes and links of ranges")
-        .setting(AppSettings::ArgRequiredElseHelp)
+        .global_setting(AppSettings::PropagateVersion)
+        .global_setting(AppSettings::ArgRequiredElseHelp)
         .subcommand(cmd_linkr::circos::make_subcommand())
         .subcommand(cmd_linkr::sort::make_subcommand())
         .subcommand(cmd_linkr::merge::make_subcommand())
@@ -18,13 +19,13 @@ fn main() -> std::io::Result<()> {
 
     // Check which subcomamnd the user ran...
     match app.get_matches().subcommand() {
-        ("circos", Some(sub_matches)) => cmd_linkr::circos::execute(sub_matches),
-        ("sort", Some(sub_matches)) => cmd_linkr::sort::execute(sub_matches),
-        ("merge", Some(sub_matches)) => cmd_linkr::merge::execute(sub_matches),
-        ("filter", Some(sub_matches)) => cmd_linkr::filter::execute(sub_matches),
-        ("clean", Some(sub_matches)) => cmd_linkr::clean::execute(sub_matches),
-        ("connect", Some(sub_matches)) => cmd_linkr::connect::execute(sub_matches),
-        (_, _) => unreachable!(),
+        Some(("circos", sub_matches)) => cmd_linkr::circos::execute(sub_matches),
+        Some(("sort", sub_matches)) => cmd_linkr::sort::execute(sub_matches),
+        Some(("merge", sub_matches)) => cmd_linkr::merge::execute(sub_matches),
+        Some(("filter", sub_matches)) => cmd_linkr::filter::execute(sub_matches),
+        Some(("clean", sub_matches)) => cmd_linkr::clean::execute(sub_matches),
+        Some(("connect", sub_matches)) => cmd_linkr::connect::execute(sub_matches),
+        _ => unreachable!(),
     }?;
 
     Ok(())
